.. _ug:

##################
Edalize User Guide
##################

The Edalize User Guide will guide you through how to use Edalize to set up and configure EDA flows and use them in your project.

The Edalize flow is divided into three stages called `configure`, `build` and `run`. The three chapters will be looking at these stages in detail.

.. include:: configure.rst
.. include:: build.rst
.. include:: run.rst

.. include:: build_runners.rst
